# Errors

- failed to resolve DisGeNet
- failed to resolve Antibody Registry
- issue parsing HGNC: max() arg is an empty sequence
- failed to resolve SwissLipids
- failed to resolve Zebrafish Information Network